@@ -22,7 +22,7 @@ import (
 	"context"
 	"database/sql/driver"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net"
 	"net/http"
 	"regexp"
@@ -30,8 +30,7 @@ import (
 	"time"
 
 	avaticaMessage "github.com/apache/calcite-avatica-go/v5/message"
-	"github.com/golang/protobuf/proto"
-	"golang.org/x/xerrors"
+	"google.golang.org/protobuf/proto"
 )
 
 var (
@@ -62,7 +61,6 @@ func NewHTTPClient(host string, baseClient *http.Client, config *Config) (*httpC
 				DialContext: (&net.Dialer{
 					Timeout:   30 * time.Second,
 					KeepAlive: 30 * time.Second,
-					DualStack: true,
 				}).DialContext,
 				MaxIdleConns:          100,
 				IdleConnTimeout:       90 * time.Second,
@@ -81,7 +79,7 @@ func NewHTTPClient(host string, baseClient *http.Client, config *Config) (*httpC
 			realm := config.principal.realm
 			cli, err := WithKerberosAuth(baseClient, user, realm, config.keytab, config.krb5Conf, config.krb5CredentialCache)
 			if err != nil {
-				return nil, xerrors.Errorf("can't add kerberos authentication to http client: %v", err)
+				return nil, fmt.Errorf("can't add kerberos authentication to http client: %w", err)
 			}
 			baseClient = cli
 		}
@@ -101,7 +99,7 @@ func (c *httpClient) post(ctx context.Context, message proto.Message) (proto.Mes
 	wrapped, err := proto.Marshal(message)
 
 	if err != nil {
-		return nil, xerrors.Errorf("error marshaling request message to protobuf: %v", err)
+		return nil, fmt.Errorf("error marshaling request message to protobuf: %w", err)
 	}
 
 	wire := &avaticaMessage.WireMessage{
@@ -112,13 +110,13 @@ func (c *httpClient) post(ctx context.Context, message proto.Message) (proto.Mes
 	body, err := proto.Marshal(wire)
 
 	if err != nil {
-		return nil, xerrors.Errorf("error marshaling wire message to protobuf: %v", err)
+		return nil, fmt.Errorf("error marshaling wire message to protobuf: %w", err)
 	}
 
 	req, err := http.NewRequest("POST", c.host, bytes.NewReader(body))
 
 	if err != nil {
-		return nil, xerrors.Errorf("error creating http request: %v", err)
+		return nil, fmt.Errorf("error creating http request: %w", err)
 	}
 
 	req.Header.Set("Content-Type", "application/x-google-protobuf")
@@ -128,15 +126,15 @@ func (c *httpClient) post(ctx context.Context, message proto.Message) (proto.Mes
 	res, err := c.httpClient.Do(req)
 
 	if err != nil {
-		return nil, xerrors.Errorf("error executing http request: %v", err)
+		return nil, fmt.Errorf("error executing http request: %w", err)
 	}
 
 	defer res.Body.Close()
 
-	response, err := ioutil.ReadAll(res.Body)
+	response, err := io.ReadAll(res.Body)
 
 	if err != nil {
-		return nil, xerrors.Errorf("error reading response body: %v", err)
+		return nil, fmt.Errorf("error reading response body: %w", err)
 	}
 
 	result := &avaticaMessage.WireMessage{}
@@ -144,19 +142,19 @@ func (c *httpClient) post(ctx context.Context, message proto.Message) (proto.Mes
 	err = proto.Unmarshal(response, result)
 
 	if err != nil {
-		return nil, xerrors.Errorf("error unmarshaling wire message: %v", err)
+		return nil, fmt.Errorf("error unmarshaling wire message: %w", err)
 	}
 
 	inner, err := responseFromClassName(result.Name)
 
 	if err != nil {
-		return nil, xerrors.Errorf("error getting wrapped response from wire message: %v", err)
+		return nil, fmt.Errorf("error getting wrapped response from wire message: %w", err)
 	}
 
 	err = proto.Unmarshal(result.WrappedMessage, inner)
 
 	if err != nil {
-		return nil, xerrors.Errorf("error unmarshaling wrapped message: %v", err)
+		return nil, fmt.Errorf("error unmarshaling wrapped message: %w", err)
 	}
 
 	if v, ok := inner.(*avaticaMessage.ErrorResponse); ok {
